@@ -4,22 +4,17 @@
  *
  * Copyright (C) 2004 NVIDIA Corporation.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of Version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU General Public License,
+ * version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See Version 2
- * of the GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the:
- *
- *           Free Software Foundation, Inc.
- *           59 Temple Place - Suite 330
- *           Boston, MA 02111-1307, USA
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
 #include <gtk/gtk.h>
@@ -34,6 +29,7 @@
 
 #include "ctkconfig.h"
 #include "ctkhelp.h"
+#include "ctkutils.h"
 
 #include "ctkdropdownmenu.h"
 
@@ -97,8 +93,7 @@ static void hsync_delay_changed(GtkSpinButton *spinbutton, gpointer user_data);
 static void vsync_delay_changed(GtkSpinButton *spinbutton, gpointer user_data);
 
 
-static void gvo_sync_event_received(GtkObject *object,
-                                    gpointer arg1,
+static void gvo_sync_event_received(GObject *object, CtrlEvent *event,
                                     gpointer user_data);
 static gint gvo_sync_probe_callback(gpointer data);
 
@@ -170,6 +165,7 @@ GType ctk_gvo_sync_get_type(void)
             sizeof (CtkGvoSync),
             0, /* n_preallocs */
             NULL, /* instance_init */
+            NULL  /* value_table */
         };
 
         ctk_gvo_sync_type =
@@ -318,7 +314,7 @@ static void update_sync_lock_status_text(CtkGvoSync *ctk_gvo_sync)
  * ctk_gvo_sync_new() - create a CtkGvoSync widget
  */
 
-GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
+GtkWidget* ctk_gvo_sync_new(CtrlTarget *ctrl_target,
                             GtkWidget *parent_window,
                             CtkConfig *ctk_config,
                             CtkEvent *ctk_event,
@@ -340,29 +336,29 @@ GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
     gint row;
 
     const char *help_text;
-    
 
-    /* make sure we have a handle */
-    
-    g_return_val_if_fail(handle != NULL, NULL);
-    
+    /* make sure we have a valid target */
+
+    g_return_val_if_fail((ctrl_target != NULL) &&
+                         (ctrl_target->h != NULL), NULL);
+
     /* create and initialize the object */
 
     object = g_object_new(CTK_TYPE_GVO_SYNC, NULL);
-    
+
     ctk_gvo_sync = CTK_GVO_SYNC(object);
-    ctk_gvo_sync->handle = handle;
+    ctk_gvo_sync->ctrl_target = ctrl_target;
     ctk_gvo_sync->parent_window = parent_window;
     ctk_gvo_sync->ctk_config = ctk_config;
     ctk_gvo_sync->ctk_event = ctk_event;
     ctk_gvo_sync->gvo_parent = gvo_parent;
-    
+
     /* Query the current GVO state */
 
     if ( !query_init_gvo_sync_state(ctk_gvo_sync) ) {
         // Free the object
         g_object_ref(object);
-        gtk_object_sink(GTK_OBJECT(object));
+        ctk_g_object_ref_sink(G_OBJECT(object));
         g_object_unref(object);
         return NULL;
     }
@@ -491,8 +487,8 @@ GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
     
     ctk_gvo_sync->sync_mode_menu = menu;
 
-    ctk_config_set_tooltip(ctk_config, CTK_DROP_DOWN_MENU(menu)->option_menu,
-                           __sync_mode_help);
+    ctk_drop_down_menu_set_tooltip(ctk_config, CTK_DROP_DOWN_MENU(menu),
+                                   __sync_mode_help);
 
     ctk_drop_down_menu_set_current_value
         (CTK_DROP_DOWN_MENU(ctk_gvo_sync->sync_mode_menu),
@@ -516,8 +512,8 @@ GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
 
     ctk_gvo_sync->sync_format_menu = menu;
 
-    ctk_config_set_tooltip(ctk_config, CTK_DROP_DOWN_MENU(menu)->option_menu,
-                           __sync_format_help);
+    ctk_drop_down_menu_set_tooltip(ctk_config, CTK_DROP_DOWN_MENU(menu),
+                                   __sync_format_help);
 
     init_sync_format_menu(ctk_gvo_sync);
 
@@ -553,11 +549,13 @@ GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
 
     /* NV_CTRL_GVO_SYNC_DELAY_PIXELS */
 
-    ret = NvCtrlGetValidAttributeValues(handle, NV_CTRL_GVO_SYNC_DELAY_PIXELS,
+    ret = NvCtrlGetValidAttributeValues(ctrl_target,
+                                        NV_CTRL_GVO_SYNC_DELAY_PIXELS,
                                         &valid);
 
     if ((ret == NvCtrlSuccess) && (valid.type == ATTRIBUTE_TYPE_RANGE)) {
-        ret = NvCtrlGetAttribute(handle, NV_CTRL_GVO_SYNC_DELAY_PIXELS, &val);
+        ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_DELAY_PIXELS,
+                                 &val);
         if (ret != NvCtrlSuccess) val = 0;
 
         if (ctk_gvo_sync->caps & NV_CTRL_GVO_CAPABILITIES_ADVANCE_SYNC_SKEW) {
@@ -605,12 +603,14 @@ GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
     }
 
     /* NV_CTRL_GVO_SYNC_DELAY_LINES */
-    
-    ret = NvCtrlGetValidAttributeValues(handle, NV_CTRL_GVO_SYNC_DELAY_LINES,
+
+    ret = NvCtrlGetValidAttributeValues(ctrl_target,
+                                        NV_CTRL_GVO_SYNC_DELAY_LINES,
                                         &valid);
 
     if ((ret == NvCtrlSuccess) && (valid.type == ATTRIBUTE_TYPE_RANGE)) {
-        ret = NvCtrlGetAttribute(handle, NV_CTRL_GVO_SYNC_DELAY_LINES, &val);
+        ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_DELAY_LINES,
+                                 &val);
         if (ret != NvCtrlSuccess) val = 0;
 
         if (ctk_gvo_sync->caps & NV_CTRL_GVO_CAPABILITIES_ADVANCE_SYNC_SKEW) {
@@ -680,7 +680,7 @@ GtkWidget* ctk_gvo_sync_new(NvCtrlAttributeHandle *handle,
 
 
 /*
- * start_menu() - Start the creation of a labled dropdown menu.  (Packs
+ * start_menu() - Start the creation of a labeled dropdown menu.  (Packs
  * the dropdown label into the table row.
  */
 
@@ -697,7 +697,7 @@ static GtkWidget *start_menu(const gchar *name, GtkWidget *table,
                      alignment, 0, 1, row, row+1, GTK_FILL, GTK_FILL,
                      TABLE_PADDING, TABLE_PADDING);
     
-    menu = ctk_drop_down_menu_new(CTK_DROP_DOWN_MENU_FLAG_MONOSPACE);
+    menu = ctk_drop_down_menu_new(CTK_DROP_DOWN_MENU_FLAG_READONLY);
     
     return menu;
 }
@@ -730,13 +730,14 @@ static void finish_menu(GtkWidget *menu, GtkWidget *table, const gint row)
 
 static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 {
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gint val;
     ReturnStatus ret;
 
 
     /* Check if this screen supports GVO */
-    
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_SUPPORTED,
+
+    ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_GVO_SUPPORTED,
                              &val);
     if ((ret != NvCtrlSuccess) || (val != NV_CTRL_GVO_SUPPORTED_TRUE)) {
         /* GVO not available */
@@ -744,15 +745,15 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
     }
 
     /* Get this GVO device's capabilities */
-    
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_CAPABILITIES,
+
+    ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_GVO_CAPABILITIES,
                              &val);
     if (ret != NvCtrlSuccess) return FALSE;
     ctk_gvo_sync->caps = val;
 
     /* Query the current input video formats */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle,
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVIO_DETECTED_VIDEO_FORMAT, &val);
     if (ret != NvCtrlSuccess) {
         val = NV_CTRL_GVIO_VIDEO_FORMAT_NONE;
@@ -761,7 +762,7 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 
     /* Query the sync mode */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_SYNC_MODE,
+    ret = NvCtrlGetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_MODE,
                              &val);
     if (ret != NvCtrlSuccess) {
         val = NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING;
@@ -770,7 +771,7 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 
     /* query COMPOSITE_SYNC_INPUT_DETECTED */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle,
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED, &val);
     if (ret != NvCtrlSuccess) {
         val = NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECTED_FALSE;
@@ -779,17 +780,17 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 
     /* query COMPOSITE_SYNC_INPUT_DETECT_MODE */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle, 
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE,
                              &val);
     if (ret != NvCtrlSuccess) {
         val = NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE_AUTO;
     }
     ctk_gvo_sync->comp_mode = val;
-    
+
     /* query SDI_SYNC_INPUT_DETECTED */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle,
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED, &val);
     if (ret != NvCtrlSuccess) {
         val = NV_CTRL_GVO_SDI_SYNC_INPUT_DETECTED_NONE;
@@ -798,7 +799,7 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 
     /* query sync source */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle,
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVO_SYNC_SOURCE,
                              &val);
     if (ret != NvCtrlSuccess) {
@@ -808,7 +809,7 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 
     /* Query framelock/genlock status */
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle,
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVO_SYNC_LOCK_STATUS,
                              &val);
     if (ret != NvCtrlSuccess) {
@@ -829,20 +830,21 @@ static gboolean query_init_gvo_sync_state(CtkGvoSync *ctk_gvo_sync)
 
 static void init_composite_termination(CtkGvoSync *ctk_gvo_sync)
 {
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     ReturnStatus ret;
     gint val;
 
     if (!ctk_gvo_sync->composite_termination_button) return;
 
-    ret = NvCtrlGetAttribute(ctk_gvo_sync->handle,
+    ret = NvCtrlGetAttribute(ctrl_target,
                              NV_CTRL_GVO_COMPOSITE_TERMINATION, &val);
     if (ret != NvCtrlSuccess) {
         val = NV_CTRL_GVO_COMPOSITE_TERMINATION_DISABLE;
     }
-    
+
     gtk_toggle_button_set_active
         (GTK_TOGGLE_BUTTON(ctk_gvo_sync->composite_termination_button),
-         ((val == NV_CTRL_GVO_COMPOSITE_TERMINATION_ENABLE) ? TRUE : FALSE));
+         val == NV_CTRL_GVO_COMPOSITE_TERMINATION_ENABLE);
 
 } /* init_composite_termination() */
 
@@ -906,7 +908,7 @@ static void register_for_gvo_sync_events(CtkGvoSync *ctk_gvo_sync)
 
 /*
  * update_gvo_sync_sensitivity() - Updates the sensitivity of various UI
- * wigets based on whether or not an input sync signal is detected.
+ * widgets based on whether or not an input sync signal is detected.
  *
  */
 
@@ -916,8 +918,7 @@ static void update_gvo_sync_sensitivity(CtkGvoSync *ctk_gvo_sync)
 
     /* Allow selection of the sync format if we're not free-running */
 
-    sensitive = (ctk_gvo_sync->sync_mode !=
-                 NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING) ? TRUE : FALSE;
+    sensitive = (ctk_gvo_sync->sync_mode != NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING);
 
     gtk_widget_set_sensitive(ctk_gvo_sync->sync_format_menu, sensitive);
 
@@ -1012,7 +1013,7 @@ static void post_sync_mode_menu_changed(CtkGvoSync *ctk_gvo_sync, gint value)
 
 
 /*
- * post_sync_format_menu_changed() - Call this function after teh sync
+ * post_sync_format_menu_changed() - Call this function after the sync
  * format has changed.
  */
 
@@ -1054,6 +1055,7 @@ static void post_sync_format_menu_changed(CtkGvoSync *ctk_gvo_sync)
 static void detect_input_toggled(GtkToggleButton *togglebutton,
                                  CtkGvoSync *ctk_gvo_sync)
 {
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gboolean enabled;
 
     enabled = gtk_toggle_button_get_active(togglebutton);
@@ -1067,7 +1069,7 @@ static void detect_input_toggled(GtkToggleButton *togglebutton,
     /* change the cursor */
 
     gdk_window_set_cursor
-        ((GTK_WIDGET(ctk_gvo_sync->parent_window))->window,
+        (ctk_widget_get_window(GTK_WIDGET(ctk_gvo_sync->parent_window)),
          ctk_gvo_sync->wait_cursor);
     
     /* make all other widgets insensitive */
@@ -1076,10 +1078,10 @@ static void detect_input_toggled(GtkToggleButton *togglebutton,
     
     /* enable REACQUIRE */
 
-    NvCtrlSetAttribute(ctk_gvo_sync->handle,
+    NvCtrlSetAttribute(ctrl_target,
                        NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE,
                        NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE_TRUE);
-    
+
     /* update the statusbar */
 
     ctk_config_statusbar_message(ctk_gvo_sync->ctk_config,
@@ -1102,13 +1104,14 @@ static void detect_input_toggled(GtkToggleButton *togglebutton,
 static gint detect_input_done(gpointer data)
 {
     CtkGvoSync *ctk_gvo_sync = CTK_GVO_SYNC(data);
-    
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
+
     /* disable REACQUIRE */
 
-    NvCtrlSetAttribute(ctk_gvo_sync->handle,
+    NvCtrlSetAttribute(ctrl_target,
                        NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE,
                        NV_CTRL_GVO_INPUT_VIDEO_FORMAT_REACQUIRE_FALSE);
-    
+
     /* reprobe */
     
     ctk_gvo_banner_probe((gpointer)(ctk_gvo_sync->gvo_parent->banner));
@@ -1139,7 +1142,7 @@ static gint detect_input_done(gpointer data)
 
     /* restore the cursor */
 
-    gdk_window_set_cursor((GTK_WIDGET(ctk_gvo_sync->parent_window))->window,
+    gdk_window_set_cursor(ctk_widget_get_window(GTK_WIDGET(ctk_gvo_sync->parent_window)),
                           NULL);
 
     /* ungrab the server */
@@ -1160,11 +1163,12 @@ static gint detect_input_done(gpointer data)
 static void composite_termination_toggled(GtkWidget *button,
                                           CtkGvoSync *ctk_gvo_sync)
 {
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gboolean enabled;
-    
+
     enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 
-    NvCtrlSetAttribute(ctk_gvo_sync->handle,
+    NvCtrlSetAttribute(ctrl_target,
                        NV_CTRL_GVO_COMPOSITE_TERMINATION,
                        (enabled ? NV_CTRL_GVO_COMPOSITE_TERMINATION_ENABLE :
                         NV_CTRL_GVO_COMPOSITE_TERMINATION_DISABLE));
@@ -1183,22 +1187,15 @@ static void composite_termination_toggled(GtkWidget *button,
 static void sync_mode_changed(CtkDropDownMenu *menu, gpointer user_data)
 {
     CtkGvoSync *ctk_gvo_sync = CTK_GVO_SYNC(user_data);
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gint value;
-    char *name;
-    
+
     value = ctk_drop_down_menu_get_current_value(menu);
-    
-    switch (value) {
-    case NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING: name = "Free Running"; break;
-    case NV_CTRL_GVO_SYNC_MODE_GENLOCK:      name = "GenLock";      break;
-    case NV_CTRL_GVO_SYNC_MODE_FRAMELOCK:    name = "FrameLock";    break;
-    default: return;
-    }
-    
-    NvCtrlSetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_SYNC_MODE, value);
-    
+
+    NvCtrlSetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_MODE, value);
+
     if (value != NV_CTRL_GVO_SYNC_MODE_FREE_RUNNING) {
-        NvCtrlSetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_SYNC_SOURCE,
+        NvCtrlSetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_SOURCE,
                            ctk_gvo_sync->sync_source);
     }
 
@@ -1218,10 +1215,11 @@ static void sync_mode_changed(CtkDropDownMenu *menu, gpointer user_data)
 static void sync_format_changed(CtkDropDownMenu *menu, gpointer user_data)
 {
     CtkGvoSync *ctk_gvo_sync = CTK_GVO_SYNC(user_data);
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gint value, sync_source, comp_mode;
 
     value = ctk_drop_down_menu_get_current_value(menu);
-    
+
     switch (value) {
     case SYNC_FORMAT_SDI:
         sync_source = NV_CTRL_GVO_SYNC_SOURCE_SDI;
@@ -1246,15 +1244,15 @@ static void sync_format_changed(CtkDropDownMenu *menu, gpointer user_data)
     ctk_gvo_sync->sync_source = sync_source;
     ctk_gvo_sync->comp_mode = comp_mode;
 
-    NvCtrlSetAttribute(ctk_gvo_sync->handle,
+    NvCtrlSetAttribute(ctrl_target,
                        NV_CTRL_GVO_SYNC_SOURCE, sync_source);
 
-    NvCtrlSetAttribute(ctk_gvo_sync->handle, 
+    NvCtrlSetAttribute(ctrl_target,
                        NV_CTRL_GVO_COMPOSITE_SYNC_INPUT_DETECT_MODE,
                        comp_mode);
 
     post_sync_format_menu_changed(ctk_gvo_sync);
-    
+
 } /* sync_format_changed() */
 
 
@@ -1267,13 +1265,13 @@ static void sync_format_changed(CtkDropDownMenu *menu, gpointer user_data)
 static void hsync_delay_changed(GtkSpinButton *spinbutton, gpointer user_data)
 {
     CtkGvoSync *ctk_gvo_sync = CTK_GVO_SYNC(user_data);
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gint val;
-    
+
     val = gtk_spin_button_get_value(spinbutton);
-    
-    NvCtrlSetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_SYNC_DELAY_PIXELS,
-                       val);
-    
+
+    NvCtrlSetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_DELAY_PIXELS, val);
+
 } /* hsync_delay_changed() */
 
 
@@ -1286,13 +1284,13 @@ static void hsync_delay_changed(GtkSpinButton *spinbutton, gpointer user_data)
 static void vsync_delay_changed(GtkSpinButton *spinbutton, gpointer user_data)
 {
     CtkGvoSync *ctk_gvo_sync = CTK_GVO_SYNC(user_data);
+    CtrlTarget *ctrl_target = ctk_gvo_sync->ctrl_target;
     gint val;
-    
+
     val = gtk_spin_button_get_value(spinbutton);
-    
-    NvCtrlSetAttribute(ctk_gvo_sync->handle, NV_CTRL_GVO_SYNC_DELAY_LINES,
-                       val);
-    
+
+    NvCtrlSetAttribute(ctrl_target, NV_CTRL_GVO_SYNC_DELAY_LINES, val);
+
 } /* vsync_delay_changed() */
 
 
@@ -1305,18 +1303,22 @@ static void vsync_delay_changed(GtkSpinButton *spinbutton, gpointer user_data)
  * NV-CONTROL events.
  */
 
-static void gvo_sync_event_received(GtkObject *object,
-                                    gpointer arg1,
+static void gvo_sync_event_received(GObject *object,
+                                    CtrlEvent *event,
                                     gpointer user_data)
 {
-    CtkEventStruct *event_struct = (CtkEventStruct *) arg1;
     CtkGvoSync *ctk_gvo_sync = CTK_GVO_SYNC(user_data);
     GtkWidget *widget;    
-    gint attribute = event_struct->attribute;
-    gint value = event_struct->value;
+    gint value;
     gboolean update_sync_format = FALSE;
 
-    switch (attribute) {
+    if (event->type != CTRL_EVENT_TYPE_INTEGER_ATTRIBUTE) {
+        return;
+    }
+
+    value = event->int_attr.value;
+
+    switch (event->int_attr.attribute) {
     case NV_CTRL_GVO_SYNC_MODE:
         ctk_gvo_sync->sync_mode = value;
         widget = ctk_gvo_sync->sync_mode_menu;
@@ -1515,30 +1517,30 @@ GtkTextBuffer* ctk_gvo_sync_create_help(GtkTextTagTable *table,
                   "SDI synchronization options.");
 
     ctk_help_heading(b, &i, "Input Video Format");
-    ctk_help_para(b, &i, __input_video_format_help);
+    ctk_help_para(b, &i, "%s", __input_video_format_help);
     ctk_help_heading(b, &i, "Input Video Format Detect");
-    ctk_help_para(b, &i, __input_video_format_detect_help);
+    ctk_help_para(b, &i, "%s", __input_video_format_detect_help);
     ctk_help_heading(b, &i, "Composite Termination");
     ctk_help_para(b, &i, "%s.  This allows the composite signal to be daisy "
                   "chained from a server load.",
                   __composite_termination_help);
     ctk_help_heading(b, &i, "Sync Mode");
-    ctk_help_para(b, &i, __sync_mode_help);
+    ctk_help_para(b, &i, "%s", __sync_mode_help);
     ctk_help_heading(b, &i, "Sync Format");
-    ctk_help_para(b, &i, __sync_format_help);
+    ctk_help_para(b, &i, "%s", __sync_format_help);
     ctk_help_heading(b, &i, "Sync Status");
-    ctk_help_para(b, &i, __sync_status_help);
+    ctk_help_para(b, &i, "%s", __sync_status_help);
 
     if ( ctk_gvo_sync->caps & NV_CTRL_GVO_CAPABILITIES_ADVANCE_SYNC_SKEW ) {
         ctk_help_heading(b, &i, "HSync Advance");
-        ctk_help_para(b, &i, __hsync_advance_help);
+        ctk_help_para(b, &i, "%s", __hsync_advance_help);
         ctk_help_heading(b, &i, "VSync Advance");
-        ctk_help_para(b, &i, __vsync_advance_help);
+        ctk_help_para(b, &i, "%s", __vsync_advance_help);
     } else {
         ctk_help_heading(b, &i, "HSync Delay");
-        ctk_help_para(b, &i, __hsync_delay_help);
+        ctk_help_para(b, &i, "%s", __hsync_delay_help);
         ctk_help_heading(b, &i, "VSync Delay");
-        ctk_help_para(b, &i, __vsync_delay_help);
+        ctk_help_para(b, &i, "%s", __vsync_delay_help);
     }
 
     ctk_help_finish(b);
